#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Copyright © 2018 Pico Technology Ltd. See LICENSE file for terms.
#
"""
This is a Python script for controlling a PicoScope 9200 Series Sampling Oscilloscope using the PicoScope 9000 COM object.
This will also work using the demo device in PicoSample3.
"""
#importación de bibliotecas
import win32com.client
import numpy as np
import matplotlib.pyplot as plt
import time
from timeit import timeit
import string
import sys
import shutil

#mensaje informativo para desconectar las entradas y realizar la autocalibración
print("Desconecte las entradas del panel local para iniciar la calibración. Introduzca 1 cuando lo haya hecho" +"\n")
ok = input()
if not ok=="1":
 sys.exit(0)
COMRCW = win32com.client.Dispatch("PicoScope9000.COMRC") #se crea un objeto COM
COMRCW.ExecCommand("Gui:RemoteLocal")  
COMRCW.ExecCommand("Ch1:Acquire 1")  #sólo se adquirirán datos a  través del canal 1
COMRCW.ExecCommand("Ch2:Acquire 0") 
COMRCW.ExecCommand("Gui:RemoteLocal") 
COMRCW.ExecCommand("Flash:Calibr:AutocalTB") #se calibra tanto la escala de tiempos como las escala vertical
COMRCW.ExecCommand("Flash:Calibr:AutocalCh")
resultado=COMRCW.ExecCommand("Flash:Calibr:AutocalResult?") #se analiza si la autocalibración ha sido exitosa
resultado=resultado[28]
time.sleep(5)
if not resultado == "0":
  sys.exit(0)
#se solicita al usuario volver a conectar la entrada para que se inicie la adquisición de datos
if resultado == "0":
 print("Por favor, conecta la entrada. Introduzca 1 cuando lo haya hecho" +"\n")
 ok = input()
 if not ok=="1":
  sys.exit(0)
print("Iniciando captura de datos" +"\n")
tiempo_ini=time.time()#se inicia un contado para poder saber el tiempo que durarán todos los procesos
print("Tiempo inicial: 0"+"\n") 
COMRCW.ExecCommand("TB:Mode A") #escala temporal modo A (sin retardos)
COMRCW.ExecCommand("TB:ScaleA 10e-4") #ajuste de la escala temporal en segundos por división
COMRCW.ExecCommand("Ch1:Display 1") #se muestra el canal 1 por pantalla
COMRCW.ExecCommand("Ch2:Display 0") #se desactiva el canal 2 por pantalla
COMRCW.ExecCommand("Acq:FitTo Single") #se ajusta la adquisición para el modo single
COMRCW.ExecCommand("Acq:Ch1:Mode Sample") #se adquieren las muestras en modo single
COMRCW.ExecCommand("Display:Ch1:Style Vectors") #se muestran las muestras por pantalla unidas por vectores
s1 = r'D:datos2\muestras\SenalGrabada.txty' #ruta de los ficheros intermedios
s2 = r'D:datos2\datos.txt' #ruta del fichero general con todas las muestras
f2 = open(s2,'w')
i = 1
cont = 1
num=5000
while i <=num: #se repite la iteracción el valor de num. Inicio de la adquisición y grabado de muestras
 COMRCW.ExecCommand("Acq:Ch1:RecLen 512") #longitud del buffer
 COMRCW.ExecCommand("Save:Memo:Source Ch1")
 COMRCW.ExecCommand("Save:Disk:NameMode Manual") 
 COMRCW.ExecCommand("Save:Disk:FileFormat YOnly") #formato de salida exponencial
 COMRCW.ExecCommand("Save:Disk:FileName D:datos2\muestras\S"+str(i)+".txty") #generación de ficheros intermedios
 COMRCW.ExecCommand("Save:Disk:Save") #almacenamiento de muestras
 i += 1
tiempo_fini=time.time()-tiempo_ini
print("Tiempo final de adquisición: " + str(tiempo_fini) + "\n") #tiempo final de adquisición

i=1
while i <=num: #inicio de la concatenación de los ficheros intermedios en uno solo
 try:
  s1 = r"D:datos2\muestras\S"+str(i)+".txty"
  f1= open(s1,'r')
 except OSError: #control de errores en los ficheros intermedios
  i += 1
 else: 
  f2 = open (s2,'a')
  contenido=f1.read()
  f2.write(contenido)       
  i += 1
f2.close()
f1.close()
tiempo_fini2=time.time()-tiempo_ini
print("Tiempo final de concatenación: " + str(tiempo_fini2) + "\n") #tiempo final de concatenación
 
